PyXMake Developer Guide: PyXMake.Tools.ErrorHandling.Error Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
PyXMake.Tools.ErrorHandling.Error Class Reference

Parent class inherited from built-in exception. More...

Inheritance diagram for PyXMake.Tools.ErrorHandling.Error:

## Additional Inherited Members
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __init__ (self, *args, **kwargs)
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Parent class inherited from built-in exception.

    Base class for all exceptions in this module.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/ErrorHandling.py